@@ -2,6 +2,7 @@
  * librdkafka - Apache Kafka C library
  *
  * Copyright (c) 2014-2022, Magnus Edenhill
+ *               2023, Confluent Inc.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -163,6 +164,11 @@ typedef enum {
         RD_KAFKA_RESOLVE_CANONICAL_BOOTSTRAP_SERVERS_ONLY,
 } rd_kafka_client_dns_lookup_t;
 
+typedef enum {
+        RD_KAFKA_GROUP_PROTOCOL_CLASSIC,
+        RD_KAFKA_GROUP_PROTOCOL_CONSUMER,
+} rd_kafka_group_protocol_t;
+
 /* Increase in steps of 64 as needed.
  * This must be larger than sizeof(rd_kafka_[topic_]conf_t) */
 #define RD_KAFKA_CONF_PROPS_IDX_MAX (64 * 33)
@@ -348,6 +354,7 @@ struct rd_kafka_conf_s {
         /* Client group configuration */
         int coord_query_intvl_ms;
         int max_poll_interval_ms;
+        int enable_metrics_push;
 
         int builtin_features;
         /*
@@ -363,8 +370,10 @@ struct rd_kafka_conf_s {
         int fetch_min_bytes;
         int fetch_queue_backoff_ms;
         int fetch_error_backoff_ms;
+        rd_kafka_group_protocol_t group_protocol;
         char *group_id_str;
         char *group_instance_id;
+        char *group_remote_assignor;
         int allow_auto_create_topics;
 
         rd_kafka_pattern_list_t *topic_blacklist;
@@ -379,6 +388,7 @@ struct rd_kafka_conf_s {
         rd_kafkap_str_t *group_protocol_type;
         char *partition_assignment_strategy;
         rd_list_t partition_assignors;
+        rd_bool_t partition_assignors_cooperative;
         int enabled_assignor_cnt;
 
         void (*rebalance_cb)(rd_kafka_t *rk,
