@@ -591,10 +591,7 @@ static void do_test_seek_to_offset_with_previous_epoch(void) {
 
 int main_0104_fetch_from_follower_mock(int argc, char **argv) {
 
-        if (test_needs_auth()) {
-                TEST_SKIP("Mock cluster does not support SSL/SASL\n");
-                return 0;
-        }
+        TEST_SKIP_MOCK_CLUSTER(0);
 
         test_timeout_set(50);
 
